smartcard.CardMonitoring.CardMonitoringThread

# ``smartcard`.`CardMonitoring`.`CardMonitoringThread``

class documentation

`class CardMonitoringThread(object):`

View In Hierarchy

Card insertion thread. This thread waits for card insertion.

Method | `__getattr__` | Undocumented
Method | `__init__` | Undocumented
Method | `join` | Undocumented
Class Variable | `instance` | Undocumented
Class | `__CardMonitoringThreadSingleton` | The real card monitoring thread class.

def __getattr__(self, name):

Undocumented

def __init__(self, observable):

Undocumented

def join(self, *args, **kwargs):

Undocumented

instance =

Undocumented